@@ -1,4 +1,5 @@
-from typing import Optional
+import dataclasses
+from typing import Dict, Optional
 
 from pydantic.dataclasses import dataclass
 from serde import deserialize
@@ -32,5 +33,13 @@ class TableauRunConfig(BaseConfig):
     access_token: Optional[TableauTokenAuthConfig]
     user_password: Optional[TableauPasswordAuthConfig]
 
-    # snowflake data source account
-    snowflake_account: Optional[str]
+    # Snowflake data source account
+    snowflake_account: Optional[str] = None
+
+    # BigQuery data source project name to project ID map
+    bigquery_project_name_to_id_map: Dict[str, str] = dataclasses.field(
+        default_factory=dict
+    )
+
+    # whether to disable Chart preview image
+    disable_preview_image: bool = False
